import greenfoot.*;

/**
 * A superbird that can be controlled by the arrowkeys: up, left, right.
 * The gun is fired by hitting the 'space' key. 'z' releases a proton wave.
 * 
 * @author Poul Henriksen
 * @author Michael Kölling
 * 
 * @version 1.1
 */
public class Superbird extends SmoothMover
{
    private static final int gunReloadTime = 5;
    private static final int protonReloadTime = 500;

    private int reloadDelayCount;
    private int protonDelayCount; 

    private GreenfootImage superbird = new GreenfootImage("SUPERBIRD.png");
    private GreenfootImage superbirdWithThrust = new GreenfootImage("SUPERBIRD.png");

    /**
     * Initialise this superbird.
     */
    public Superbird()
    {
        reloadDelayCount = 5;
        protonDelayCount = 500;
        addToVelocity(new Vector(13, 0.7));
    }

    /**
     * Do what a superbird's gotta do. (Which is: mostly flying about, and turning,
     * accelerating and shooting when the right keys are pressed.)
     */
    public void act()
    {
        checkKeys();
        reloadDelayCount++;
        protonDelayCount++;
        move();
        checkCollision();
    }

    /**
     * Check whether there are any key pressed and react to them.
     */
    private void checkKeys() 
    {
        if (Greenfoot.isKeyDown("space")) 
        {
            fire();
        }
        if (Greenfoot.isKeyDown("left")) 
        {
            turn(-5);
        }
        if (Greenfoot.isKeyDown("right")) 
        {
            turn(5);
        }
        if (Greenfoot.isKeyDown("z")) 
        {
            startProtonWave();
        }
        ignite(Greenfoot.isKeyDown("up"));
    }

    public void startProtonWave()
    {      
        if (protonDelayCount >= protonReloadTime) 
        {
            ProtonWave wave = new ProtonWave();
            getWorld().addObject (wave, getX(), getY());
            protonDelayCount=0;
        }
    }

    /**
     * makes the superbird accelerate in the direction it is pointing in
     */
    private void ignite(boolean boosterOn) 
    {
        if (boosterOn) 
        {
            setImage(superbirdWithThrust);
            addToVelocity(new Vector(getRotation(), 0.3));
            // // }
            // // else 
            // // {
            // // setImage(superbird);        
            // // }
        }
    }

    public void checkCollision()
    {
        Bird a = (Bird) getOneIntersectingObject(Superbird.class);
        if (a != null) 
        {
            Park park = (Park) getWorld();
            park.addObject(new Explosion(), getX(), getY());
            park.removeObject(this);
            // park.gameOver();
        }
    }

    /**
     * Fire a worm if the gun is ready.
     */
    private void fire() 
    {
        if (reloadDelayCount >= gunReloadTime) 
        {
            Worm worm = new Worm (getVelocity(), getRotation());
            getWorld().addObject (worm, getX(), getY());
            worm.move ();
            reloadDelayCount = 0;
        }
    }

}