import greenfoot.*;

/**
 * A worm that can hit birds.
 * 
 * @author Poul Henriksen
 * @author Michael Kölling
 */
public class Worm extends SmoothMover
{
    /** The damage this worm will deal */
    private static final int damage = 16;
    
    /** A worm looses one life each act, and will disappear when life = 0 */
    private int life = 30;
    
    /**
     * Default constructor for testing.
     */
    public Worm()
    {
        GreenfootImage image = getImage();
        image.scale(50, 90);
        setImage(image);
    }
    
    /**
     * Create a worm with given speed and direction of movement.
     */
    public Worm(Vector speed, int rotation)
    {
        super(speed);
        setRotation(rotation);
        addToVelocity(new Vector(rotation, 15));
        Greenfoot.playSound("EnergyGun.wav");
    }
    
    /**
     * The worm will damage birds if it hits them.
     */
    public void act()
    {
        if(life <= 0) {
            getWorld().removeObject(this);
        } 
        else {
            life--;
            move();
            checkBirdHit();
        }
    }
    
    /**
     * Check whether we have hit an bird.
     */
    private void checkBirdHit()
    {
        Bird bird = (Bird) getOneIntersectingObject(Bird.class);
        if (bird != null)
        {
            getWorld().removeObject(this);
            bird.hit(damage);
        }
    }
}